"""
    Setup file for uetai.
    Use setup.cfg to configure your project.
"""
import os
from pathlib import Path
from importlib.util import module_from_spec, spec_from_file_location
from setuptools import find_packages, setup


# Read the contents of README file
source_root = Path(".")
with (source_root / "README.md").open(encoding="utf-8") as f:
    long_description = f.read()

# Read the requirements
with (source_root / "requirements.txt").open(encoding="utf8") as f:
    requirements = f.readlines()

docs = (
    "UETAI is data validation and model debugger tools"
    " integrated with ML experiment tracking tools"
)

version = "0.1.1"

with (source_root/"src/uetai/version.py").open("w+", encoding="utf-8") as f:
    f.writelines([
        '"""This file is auto-generated by setup.py, please do not alter."""\n',
        f'__version__ = "{version}"\n',
        "",
    ])

setup(
    name="uetai",
    version=version,
    description=docs,
    packages=find_packages("src", exclude=["tests*"]),
    package_dir={"": "src"},
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="UET AILab",
    author_email="ailab@vnu.edu.vn",
    url="https://github.com/UETAILab/uetai",
    license="MIT",
    install_requires=requirements,
    zip_safe=False,
    keywords=["deep learning", "AI",],
    python_requires=">=3.7",
    setup_requires=[],
    include_package_data=True,
    project_urls={
        "Bug Tracker": "https://github.com/UETAILab/uetai/issues",
        "Documentation": "https://uetailab.github.io/uetai/",
        "Source Code": "https://github.com/UETAILab/uetai",
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    entry_points={
        "console_scripts": [
            "uetai = uetai.cli:run",
        ]
    },
    options={"bdist_wheel": {"universal": True}},
)
